Credits
*******

..
  From https://stackoverflow.com/a/10766650/3956024

If you use this library for your research,
please cite our paper:

`F. Pérez-García, R. Sparks, and S. Ourselin. TorchIO: a Python library for
efficient loading, preprocessing, augmentation and patch-based sampling of
medical images in deep learning. Computer Methods and Programs in Biomedicine
(June 2021), p. 106236. ISSN:
0169-2607.doi:10.1016/j.cmpb.2021.106236. <https://doi.org/10.1016/j.cmpb.2021.106236>`_


BibTeX:

.. code-block:: latex

   @article{perez-garcia_torchio_2021,
      title = {{TorchIO}: a {Python} library for efficient loading, preprocessing, augmentation and patch-based sampling of medical images in deep learning},
      journal = {Computer Methods and Programs in Biomedicine},
      pages = {106236},
      year = {2021},
      issn = {0169-2607},
      doi = {https://doi.org/10.1016/j.cmpb.2021.106236},
      url = {https://www.sciencedirect.com/science/article/pii/S0169260721003102},
      author = {P{\'e}rez-Garc{\'i}a, Fernando and Sparks, Rachel and Ourselin, S{\'e}bastien},
   }

This project is supported by the following institutions:

* `Engineering and Physical Sciences Research Council (EPSRC) & UK Research and Innovation (UKRI) <https://epsrc.ukri.org/>`_
* `EPSRC Centre for Doctoral Training in Intelligent, Integrated Imaging In Healthcare (i4health) <https://www.ucl.ac.uk/intelligent-imaging-healthcare/>`_ (University College London)
* `Wellcome / EPSRC Centre for Interventional and Surgical Sciences (WEISS) <https://www.ucl.ac.uk/interventional-surgical-sciences/>`_ (University College London)
* `School of Biomedical Engineering & Imaging Sciences (BMEIS) <https://www.kcl.ac.uk/bmeis>`_ (King's College London)

This library has been greatly inspired by
`NiftyNet <https://github.com/NifTK/NiftyNet>`_, which is no longer maintained.
